# Internal Developer Docset

For maintainers building trace core systems.

## Priority Reading

1. [Internal Architecture](./architecture.md)
2. `docs/02-architecture/`
3. `docs/reference/`
4. `docs/checklists/` and `docs/runbooks/`

## Source Areas

- `backend/`
- `frontend/`
- `tests/`
- `scripts/`
